Omblog is a django based blog system designed to have a smooth, minimal writing experience so it's a joy to use and be heavily cached so it can take a battering. 

It is currently being worked on after a long break, however please be
aware that at this current time there is no default frontend skin for
displaying your posts, there is only the UI for creating / editing.

[The documentation will help you get started](http://django-omblog.readthedocs.org/)

If you're looking for a blog that you can style to death that can take a
battering, then give omblog a try.

![The writing UI](http://django-omblog.readthedocs.org/en/latest/_images/create-3.png)

## Current Features

* Minimal UI for writing posts
* Drag and drop image uploading with automatic thumbnailing
* Syntax highlighting
* Keyboard shortcut to save posts
* Tab key inserts 4 spaces and doesn't bounce out of the writingarea.
* If you have Django's cache backend configured, it can take a battering.


## Credits

The following JS libraries / plugins are included in omblog; many thanks
is extended to the authors for their fine, fine work.

* [jQuery](http://jquery.com/)
* [ICanHaz.js](http://icanhazjs.com/)
* [jquery.autosize.js](https://github.com/jackmoore/autosize)
* [mousetrap.js](http://craig.is/killing/mice)
* [jquery.slugify](http://patrickmcelhaney.com/jQuery-Slugify-Plugin/)
 
